<?php

declare(strict_types=1);

namespace Drupal\book_library\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\book_library\GenreInterface;

/**
 * Defines the genre entity class.
 *
 * @ContentEntityType(
 *   id = "genre",
 *   label = @Translation("Genre"),
 *   label_collection = @Translation("Genres"),
 *   label_singular = @Translation("genre"),
 *   label_plural = @Translation("genres"),
 *   label_count = @PluralTranslation(
 *     singular = "@count genres",
 *     plural = "@count genres",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\book_library\GenreListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\book_library\Form\GenreForm",
 *       "edit" = "Drupal\book_library\Form\GenreForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\Core\Entity\Form\DeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "genre",
 *   admin_permission = "administer genre",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "field_genre_title",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "collection" = "/admin/content/genre",
 *     "add-form" = "/admin/content/book/genre/add",
 *     "canonical" = "/admin/content/book/genre/{genre}",
 *     "edit-form" = "/admin/content/book/genre/{genre}/edit",
 *     "delete-form" = "/admin/content/book/genre/{genre}/delete",
 *     "delete-multiple-form" = "/admin/content/genre/delete-multiple",
 *   },
 *   field_ui_base_route = "entity.genre.settings",
 * )
 */
final class Genre extends ContentEntityBase implements GenreInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['field_genre_title'] = BaseFieldDefinition::create('string')
   ->setLabel(t('Genre'))
   ->setRequired(TRUE)
   ->setSettings([
    'max_length' => 255,
   ])
   ->setDisplayOptions('form', [
    'type'   => 'string_textfield',
    'weight' => 0,
   ])
   ->setDisplayOptions('view', [
    'type'   => 'string',
    'label'  => 'above',
    'weight' => 0,
   ])
   ->setDisplayConfigurable('form', TRUE)
   ->setDisplayConfigurable('view', TRUE);

    return $fields;
  }

}
