<?php

namespace Drupal\book_library\Plugin\rest\resource;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\rest\Attribute\RestResource;
use Drupal\rest\ResourceResponse;
use Drupal\rest\Plugin\ResourceBase;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

#[RestResource(
    id: 'book_collection_resource',
    label: new TranslatableMarkup('Book Collection Resource'),
    uri_paths: [
        'canonical' => '/api/v1/books', // Note the plural "books"
    ],
)]
class BookCollectionResource extends ResourceBase {

    protected $entityTypeManager;

    public function __construct(
        array $configuration,
        $plugin_id,
        $plugin_definition,
        array $serializer_formats,
        LoggerInterface $logger,
        EntityTypeManagerInterface $entityTypeManager
    ) {
        parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
        $this->entityTypeManager = $entityTypeManager;
    }

    public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
        return new self(
            $configuration,
            $plugin_id,
            $plugin_definition,
            $container->getParameter('serializer.formats'),
            $container->get('logger.factory')->get('rest'),
            $container->get('entity_type.manager')
        );
    }

    public function permissions() {
        return [
            'view books collection' => ['title' => 'View Books Collection'],
        ];
    }

    public function get(): ResourceResponse {
        // Load all books in a collection that are Available.
        $entityStorage = $this->entityTypeManager->getStorage('book');
        $query = $entityStorage->getQuery();
        $query->accessCheck(FALSE);
        $query->condition('field_book_status', 1);
        $entityIds = $query->execute();
        if (empty($entityIds)) {
            return new ResourceResponse([]);
        }
        $entities = $entityStorage->loadMultiple($entityIds);
        $bookData = [];
        foreach ($entities as $entity) {
            $bookData[] = [
                'id' => $entity->id(),
                'title' => $entity->label(),
                'author' => $entity->get('field_book_author')->value,
                'publication_year' => $entity->get('field_book_publication_year')->value,
                'description' => $entity->get('field_book_description')->value,
                'genre' => $entity->get('field_book_genre')->value,
            ];
        }
        return new ResourceResponse($bookData);
    }
}